'use strict';

var fs = require('fs');
var path = require('path');
var argv = require('yargs').argv;
var omit = require('lodash/omit');
var createWebpackConfig = require('./createWebpackConfig');

console.log('reading ' + process.cwd() + '/lolla.json');

var createConfigsFromLolla = function createConfigsFromLolla() {
  var lollaFile = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : process.cwd() + '/lolla.json';

  try {
    var lollaJSON = JSON.parse(fs.readFileSync(lollaFile, 'utf-8'));
    var configs = [];
    lollaJSON.packages.forEach(function (pkg) {
      if (pkg.ignore) return console.log('ignore package: ' + pkg.context);
      try {
        configs.push(createWebpackConfig(Object.assign({
          __DEV__: !(process.env.NODE_ENV === 'production') && !argv.production,
          compress: argv.compress
        }, omit(lollaJSON, ['packages']), pkg, {
          context: path.resolve(process.cwd(), pkg.context)
        })));
      } catch (e) {
        console.log('valid fail, context\': ' + pkg.context);
        console.log(e);
      }
    });
    return configs;
  } catch (e) {
    console.log('Could not find lolla.json or format error');
    console.log(e);
    return [];
  }
};

module.exports = createConfigsFromLolla;