'use strict';

var express = require('express');
var webpack = require('webpack');
var argv = require('yargs').argv;
var cors = require('cors');
var compression = require('compression');
var webpackDevMiddleware = require('webpack-dev-middleware');
var webpackHotMiddleware = require('webpack-hot-middleware');
var serveIndex = require('serve-index');

var createConfigsFromLolla = require('./createConfigsFromLolla');

var hotMiddlewareScript = 'webpack-hot-middleware/client?path=/__webpack_hmr&timeout=20000&reload=true';

module.exports.start = function () {
  var packages = createConfigsFromLolla();

  var app = express();

  app.use(cors());
  app.use(compression());

  packages.forEach(function (target) {
    Object.keys(target.entry, function (key) {
      target.entry[key].push(hotMiddlewareScript);
    });
    target.devtool = 'inline-source-map';
    if (target.hot) target.plugins.push(new webpack.HotModuleReplacementPlugin());
    target.plugins.push(new webpack.NoEmitOnErrorsPlugin());

    target.devServer = {
      hot: true,
      inline: true
    };

    console.log(target.output.publicPath);

    var compiler = webpack(target);
    app.use(webpackDevMiddleware(compiler, {
      publicPath: target.output.publicPath,
      stats: {
        colors: true
      }
    }));
    if (target.hot) app.use(webpackHotMiddleware(compiler));
  });

  app.route('*').all(express.static(process.cwd()), serveIndex(process.cwd(), { icons: true }));

  var port = argv.port || process.env.PORT || 9090;

  app.listen(port, function (err) {
    if (err) return console.log(err);
    console.log('webpack:  Listening at http://localhost:' + port);
  });

  console.warn('lolla: you should install loaders in this project directory');
};